<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-porte_plume?lang_cible=es
// ** ne pas modifier le fichier **

return [

	// P
	'porte_plume_description' => 'Porta pluma es una barra de herramientas extensible para SPIP que utiliza la librería javascript [MarkItUp->http://markitup.jaysalvat.com/home/]',
	'porte_plume_nom' => 'Porta pluma',
	'porte_plume_slogan' => 'Una barra de herramientas para escribir bien',
];
